<?php
/*-----------------------------------------------------------------------------------*/
/* This theme supports WooCommerce, woo! */
/*-----------------------------------------------------------------------------------*/

add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
	add_theme_support( 'woocommerce' );
}


/*-----------------------------------------------------------------------------------*/
/* Any WooCommerce overrides and functions can be found here
/*-----------------------------------------------------------------------------------*/

// Disable WooCommerce styles
if ( version_compare( WOOCOMMERCE_VERSION, '2.1' ) >= 0 ) {
    // WooCommerce 2.1 or above is active
    add_filter( 'woocommerce_enqueue_styles', '__return_false' );
} else {
    // WooCommerce less than 2.1 is active
    define( 'WOOCOMMERCE_USE_CSS', false );
}

// Remove WC sidebar
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );

// Adjust markup on all WooCommerce pages
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

add_action( 'woocommerce_before_main_content', 'coquette_before_content', 10 );
add_action( 'woocommerce_after_main_content', 'coquette_after_content', 20 );

// Fix the layout etc
if (!function_exists('coquette_before_content')) {
	function coquette_before_content() {
	?>
		<!-- #content Starts -->
		<?php woo_content_before(); ?>
	    <div id="content" class="col-full">

	        <!-- #main Starts -->
	        <?php woo_main_before(); ?>
	        <div id="main" class="col-left">
	    <?php
	}
}

if (!function_exists('coquette_after_content')) {
	function coquette_after_content() {
	?>
			<?php if ( is_search() && is_post_type_archive() ) { add_filter( 'woo_pagination_args', 'woocommerceframework_add_search_fragment', 10 ); add_filter( 'woo_pagination_args_defaults', 'woocommerceframework_woo_pagination_defaults', 10 ); } ?>
			<?php woo_pagenav(); ?>
			</div><!-- /#main -->
	        <?php woo_main_after(); ?>

	    </div><!-- /#content -->
		<?php woo_content_after(); ?>
	    <?php
	}
}

function woocommerceframework_add_search_fragment ( $settings ) {
	$settings['add_fragment'] = '&post_type=product';
	return $settings;
} // End woocommerceframework_add_search_fragment()

function woocommerceframework_woo_pagination_defaults ( $settings ) {
	$settings['use_search_permastruct'] = false;

	return $settings;
} // End woocommerceframework_woo_pagination_defaults()


// Add the WC sidebar in the right place
add_action( 'woo_main_after', 'woocommerce_get_sidebar', 10 );

// Remove breadcrumb (we're using the WooFramework default breadcrumb)
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
add_action( 'woocommerce_before_main_content', 'coquette_breadcrumb', 20, 0 );

function coquette_breadcrumb() {
	global  $woo_options;
	if ( $woo_options[ 'woo_breadcrumbs_show' ] == 'true' ) {
		woo_breadcrumbs();
	}
}

// Remove pagination (we're using the WooFramework default pagination)
remove_action( 'woocommerce_pagination', 'woocommerce_pagination', 10 ); // < 2.0

if ( version_compare( WOOCOMMERCE_VERSION, '2.0', '>=' ) ) {
	remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 ); // 2.0 +
}

// Adjust the star rating in the sidebar
add_filter( 'woocommerce_star_rating_size_sidebar', 'coquette_star_sidebar' );

if (!function_exists('coquette_star_sidebar')) {
	function coquette_star_sidebar() {
		return 12;
	}
}

// Adjust the star rating in the recent reviews
add_filter( 'woocommerce_star_rating_size_recent_reviews', 'coquette_star_reviews' );

if (!function_exists('coquette_star_reviews')) {
	function coquette_star_reviews() {
		return 12;
	}
}

// Change columns in product loop to 2
add_filter( 'loop_shop_columns', 'coquette_loop_columns' );

if (!function_exists('coquette_loop_columns')) {
	function coquette_loop_columns() {
		return 2;
	}
}

// Remove sidebar on single shop pages
add_action( 'wp_head', 'coquette_remove_sidebar' );

function coquette_remove_sidebar() {
	if ( is_singular( array( 'product' ) ) ) remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
}

// Move tabs and related products outside of div.post
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10 );
add_action( 'woocommerce_after_single_product', 'woocommerce_output_product_data_tabs', 0 );

// Move upsells / related products
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);

add_action( 'woocommerce_after_single_product', 'woocommerce_upsell_display', 15 );
add_action( 'woocommerce_after_single_product', 'woocommerce_output_related_products', 20);

// Redefine woocommerce_output_related_products()
if ( ! function_exists( 'woocommerce_output_related_products' ) && version_compare( WOOCOMMERCE_VERSION, "2.1" ) < 0 ) {
	function woocommerce_output_related_products() {
		woocommerce_related_products(4,2); // Display 3 products in rows of 3
	}
}
add_filter( 'woocommerce_output_related_products_args', 'superstore_related_products' );
function superstore_related_products() {
	$args = array(
		'posts_per_page' => 4,
		'columns'        => 2,
	);
	return $args;
}

if ( ! function_exists( 'woo_upsell_display' ) ) {
	function woo_upsell_display() {
	    // Display up sells in correct layout.
	    woocommerce_upsell_display( -1, 2 );
	}
}

// Move the price below the excerpt on the single product page
remove_action( 'woocommerce_template_single_summary', 'woocommerce_template_single_price', 10, 2 );
add_action( 'woocommerce_template_single_summary', 'woocommerce_template_single_price', 25, 2 );

// Add button to sub categories in products loop
add_action( 'woocommerce_after_subcategory_title', 'coquette_subcat_button', 10, 2 );

if (!function_exists('coquette_subcat_button')) {
	function coquette_subcat_button( $category ) {
		global $woocommerce;
		echo '<a href="'.get_term_link( $category->slug, 'product_cat' ).'" class="button">'.__( 'View Products', 'woothemes' ).'</a>';
	}
}

// Handle cart in header fragment for ajax add to cart
add_filter( 'add_to_cart_fragments', 'coquette_header_add_to_cart_fragment' );

if (!function_exists('coquette_header_add_to_cart_fragment')) {
	function coquette_header_add_to_cart_fragment( $fragments ) {
		global $woocommerce;

		$fragments['#btn-cart'] = '
		<div id="btn-cart" class="fr">
	    	<a href="'.$woocommerce->cart->get_cart_url().'" title="'.__( 'View your shopping cart', 'woothemes' ).'">
				<span class="btn-cart-inner">'.sprintf( _n( '%d item &ndash; ', '%d items &ndash; ', $woocommerce->cart->get_cart_contents_count(), 'woothemes' ), $woocommerce->cart->get_cart_contents_count() ) . $woocommerce->cart->get_cart_total() . '</span>
			</a>
	    </div>
		';

		return $fragments;

	}
}
